nlsq.least_squares module
==========================

This module contains the core least squares solver implementation.

.. automodule:: nlsq.core.least_squares
   :members:
   :noindex:
   :undoc-members:
   :show-inheritance:
